@@ -7,12 +7,11 @@
 #' for features including plotting of residuals, the use of sampling weights, and corrected
 #' variance estimation.
 #'
-#' @docType package
 #' @name eventglm
 #' @references Sachs MC, Gabriel EE (2022). "Event History Regression with Pseudo-Observations: Computational Approaches and an Implementation in R." Journal of Statistical Software, 102(9), 1-34. <doi:10.18637/jss.v102.i09>
 #' @useDynLib eventglm, .registration=TRUE
 #' @importFrom stats coef model.frame model.matrix model.response .getXlevels model.offset model.weights naprint pnorm predict quasi residuals residuals.glm terms update as.formula update.formula reformulate vcov qnorm setNames coefficients
-NULL
+"_PACKAGE"
 
 #' @importFrom survival Surv
 #' @export
